@@ -128,14 +128,16 @@ class AllEntityManager(ActivatableManager):
         """
         Given a saved entity model object, return the associated entity.
         """
-        return self.get(entity_type=ContentType.objects.get_for_model(entity_model_obj), entity_id=entity_model_obj.id)
+        return self.get(entity_type=ContentType.objects.get_for_model(
+            entity_model_obj, for_concrete_model=False), entity_id=entity_model_obj.id)
 
     def delete_for_obj(self, entity_model_obj):
         """
         Delete the entities associated with a model object.
         """
         return self.filter(
-            entity_type=ContentType.objects.get_for_model(entity_model_obj), entity_id=entity_model_obj.id).delete(
+            entity_type=ContentType.objects.get_for_model(
+                entity_model_obj, for_concrete_model=False), entity_id=entity_model_obj.id).delete(
             force=True)
 
     def active(self):
